@@ -14,21 +14,23 @@ See the License for the specific language governing permissions and
 limitations under the License.
 """
 
-__version__ = "1.1.15"
+__version__ = "1.1.17"
+import cvxpy.interface.scipy_wrapper
 from cvxpy.atoms import *
-from cvxpy.constraints import NonPos, Zero, SOC, PSD
+from cvxpy.constraints import PSD, SOC, NonPos, Zero
+from cvxpy.error import (DCPError, DGPError, DPPError, SolverError,
+                         disable_warnings, enable_warnings, warnings_enabled,)
+from cvxpy.expressions.constants import CallbackParam, Constant, Parameter
 from cvxpy.expressions.expression import Expression
 from cvxpy.expressions.variable import Variable
-from cvxpy.expressions.constants import Parameter, CallbackParam, Constant
-from cvxpy.problems.problem import Problem
 from cvxpy.problems.objective import Maximize, Minimize
-import cvxpy.interface.scipy_wrapper
-from cvxpy.error import DCPError, DPPError, DGPError, SolverError, disable_warnings, enable_warnings, warnings_enabled
-from cvxpy.settings import (CVXOPT, GLPK, GLPK_MI, CBC, CPLEX, OSQP, NAG,
-                            ECOS, SCS, DIFFCP, GUROBI, MOSEK, XPRESS, SCIP, SCIPY, ECOS_BB,
-                            OPTIMAL, UNBOUNDED, INFEASIBLE, SOLVER_ERROR, ROBUST_KKTSOLVER,
-                            OPTIMAL_INACCURATE, UNBOUNDED_INACCURATE, INFEASIBLE_INACCURATE, USER_LIMIT)
-from cvxpy.settings import get_num_threads, set_num_threads
+from cvxpy.problems.problem import Problem
 from cvxpy.transforms import linearize, partial_optimize, suppfunc
 from cvxpy.reductions import *
 from cvxpy.reductions.solvers.defines import installed_solvers
+from cvxpy.settings import (CBC, CPLEX, CVXOPT, DIFFCP, ECOS, ECOS_BB, GLPK,
+                            GLPK_MI, GUROBI, INFEASIBLE, INFEASIBLE_INACCURATE,
+                            MOSEK, NAG, OPTIMAL, OPTIMAL_INACCURATE, OSQP,
+                            ROBUST_KKTSOLVER, SCIP, SCIPY, SCS, SOLVER_ERROR,
+                            UNBOUNDED, UNBOUNDED_INACCURATE, USER_LIMIT,
+                            XPRESS, get_num_threads, set_num_threads,)
